==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Circle/CircleTPR/ts/CircleTPR_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ArcTPR</name>
    <message>
        <source>Choose solution</source>
        <translation type="obsolete">ソリューション</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="obsolete">解決法がありません</translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="obsolete">第１の線分,弧または円</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="obsolete">第２の線分,弧または円</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="obsolete">点</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="obsolete">ソリューション</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="obsolete">解決法がありません</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="obsolete">&amp;g 1点と2接線</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="obsolete">２つのエンティティに接し１点を通る円を描画</translation>
    </message>
</context>
<context>
    <name>CircleTPR</name>
    <message>
        <location filename="../CircleTPR.js" line="+39"/>
        <source>Point on circle</source>
        <translation>点</translation>
    </message>
    <message>
        <location filename="../CircleTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle tangential to entity, through point with radius</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CircleTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>半径:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Circle/CircleTPR/ts/CircleTPR_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ArcTPR</name>
    <message>
        <source>Choose solution</source>
        <translation type="obsolete">ソリューション</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="obsolete">解決法がありません</translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="obsolete">第１の線分,弧または円</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="obsolete">第２の線分,弧または円</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="obsolete">点</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="obsolete">ソリューション</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="obsolete">解決法がありません</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="obsolete">&amp;g 1点と2接線</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="obsolete">２つのエンティティに接し１点を通る円を描画</translation>
    </message>
</context>
<context>
    <name>CircleTPR</name>
    <message>
        <location filename="../CircleTPR.js" line="+39"/>
        <source>Point on circle</source>
        <translation>点</translation>
    </message>
    <message>
        <location filename="../CircleTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation>正接,点,半径</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle tangential to entity, through point with radius</source>
        <translation>指定した半径で点を通る、エンティティに接する円を描く</translation>
    </message>
    <message>
        <location filename="../CircleTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>半径:</translation>
    </message>
</context>
</TS>
